#!/bin/sh
#Script checks the size of the access.log file and rotates it if it is
# larger than MAX_LOG, or it is 0 am . Also, fill the awstats database. 
#
# Doug Teodoro, Barry Blumenfeld, Lee Lueking. 4 Dec. 2006
# Modified by Dave Dykstra September 2007
# Modified by Barry Blumenfeld October 2007 to squid log reformatting and compression
# Further updated by Dave Dykstra November 2009 to be able to upload to
#   CERN from outside
#
# Set AWSTATS_FLAG to maximum minute in each hour so awstats is only updated
#  once per hour even if this script is in crontab multiple times per hour.
#  Valid values are 0 to 60; set to 60 if you want to run or test it any time.
AWSTATS_FLAG=05

# Directory squid logs are installed in
PATH_LOG=/data/squid_logs

#Size of log file to initiatate early rotation
MAX_LOG=2000000000

#Directory squid is installed in
SQUID_DIR=/home/dbfrontier/local/lib/frontier/frontier-cache/squid

#Directory awstats program and password-file is installed in
AWSTATS_DIR=/home/dbfrontier/local/lib/awstats

#Site (e.g. cern)
SITE=cern

#Name for this machine on the awstats webserver
AWSTATS_CONFIG=""  # hardcode or set in the below "for" loop

#Project (e.g. cms or atlas)
PROJ=""  # hardcode or set in the below "for" loop

#if AWSTATS_CONFIG and PROJ are hardcoded, this loop can be deleted
#  or it may be used as an example to look up site-specific aliases
THISNODE=`uname -n`
for P in cms atlas; do
    for N in 1 2 3 4 5; do
	NODE=${P}frontier$N
	case `host $NODE 2>/dev/null` in
	    *"is an alias for $THISNODE"*)
		AWSTATS_CONFIG=$NODE
		PROJ=$P
		break
		;;
	esac
    done
done


# ----- the rest of the script should not need to be customized --------
# ----- unless uploading to a server other than frontier.cern.ch -------
AWSTATS_LOGNAME=

MIN_EXE=`date +%H%M`               

echo `date`

GET_SIZE=$(stat -c %s $PATH_LOG/access.log)      #size of the log file

if [ "$GET_SIZE" -ge "$MAX_LOG" ] || [ "$MIN_EXE" -eq "0000" ] || [ "$MIN_EXE" -eq "0001" ]; then #test the size and
   echo "access_log >= $MAX_LOG Bytes or 0:00 AM -> Rotating the log file..."         #time to see if it should
   echo "Size of log file: $GET_SIZE"                                                                 #rotate or not
   echo "HourMinute (HHMM) of execution: $MIN_EXE"

   echo "Rotate the squid log" 
   $SQUID_DIR/sbin/squid -k rotate 
   sleep 20   # pause a bit to let the rotation finish
   AWSTATS_LOGNAME=$PATH_LOG/access.log.0
   # save the entries that resulted in reloading (because the database
   #   was modified) in a separate log file, saved longer
   grep '" 200 .* GMT"' $AWSTATS_LOGNAME >>$PATH_LOG/modifiedqueries.log
else
   echo "It's not necessary to rotate!"
   # Set AWSTATS_FLAG to 05 so this is only done once per hour
   if [ `date +%M` -lt $AWSTATS_FLAG ]; then
      AWSTATS_LOGNAME=$PATH_LOG/access.log
   fi
fi

if [ -n "$AWSTATS_LOGNAME" ] && [ -n "$AWSTATS_CONFIG" ]; then
   echo "Calculating awstats"
   if [ ! -f $AWSTATS_DIR/awstats.$AWSTATS_CONFIG.conf ]
   then
      echo "Creating $AWSTATS_DIR/awstats.$AWSTATS_CONFIG.conf"
      # this is needed to get the node name into the awstats*.txt files
      sed '/^DirData/s,=.*,="'$AWSTATS_DIR/$AWSTATS_CONFIG'",' $AWSTATS_DIR/awstats.conf >$AWSTATS_DIR/awstats.$AWSTATS_CONFIG.conf
   fi
   if [ ! -d $AWSTATS_DIR/$AWSTATS_CONFIG ]; then
      mkdir $AWSTATS_DIR/$AWSTATS_CONFIG
   fi
#  Monthly stats
   $AWSTATS_DIR/awstats.pl -update -LogFile=$AWSTATS_LOGNAME -config=$AWSTATS_CONFIG 
#  Daily stats
   $AWSTATS_DIR/awstats.pl -update -LogFile=$AWSTATS_LOGNAME -config=$AWSTATS_CONFIG -databasebreak=day
#  Delete stats files older than one month, plus a little bit in case
#   transfers are down for a short while
   find $AWSTATS_DIR/$AWSTATS_CONFIG -mtime +40 | xargs -t rm -f
#  Transfer to frontier server for publishing
   rsync --password-file=$AWSTATS_DIR/password-file -av $AWSTATS_DIR/$AWSTATS_CONFIG $SITE$PROJ@frontier.cern.ch::awstats-$SITE$PROJ
fi
